==> hal-testsuite-common-0.0.4-sources.jar: org/jboss/hal/testsuite/fragment/config/datasource/DatasourceWizard.java <==
package org.jboss.hal.testsuite.fragment.config.datasource;

import org.jboss.arquillian.graphene.Graphene;
import org.jboss.hal.testsuite.fragment.shared.modal.WizardWindow;
import org.jboss.hal.testsuite.fragment.shared.table.ResourceTableFragment;
import org.jboss.hal.testsuite.fragment.shared.util.ResourceManager;
import org.jboss.hal.testsuite.util.Console;
import org.jboss.hal.testsuite.util.PropUtils;
import org.openqa.selenium.By;

/**
 * @author jcechace
 */
public class DatasourceWizard extends WizardWindow {

    private static final By DETECTED_DRIVER_BUTTON = By.xpath(".//div[text()='Detected Driver']");

    public TestConnectionWindow testConnection() {
        String label = PropUtils.get("config.datasources.configarea.connection.test.label");
        clickButton(label);
        Console.withBrowser(browser).waitUntilFinished();

        String windowTitle =  PropUtils.get("config.datasources.window.connection.test.head.label");
        TestConnectionWindow window =  Console.withBrowser(browser)
                .openedWindow(windowTitle, TestConnectionWindow.class);

        return window;
    }

    public void switchToDetectedDriver() {
        root.findElement(DETECTED_DRIVER_BUTTON).click();
    }

    public ResourceTableFragment getResourceTable() {
        return Graphene.createPageFragment(ResourceManager.class, root).getResourceTable();
    }

    public void selectDriver(String driverName) {
        getResourceTable().selectRowByText(0, driverName);
    }

}

==> hal-testsuite-common-0.0.5-sources.jar: org/jboss/hal/testsuite/fragment/config/datasource/DatasourceWizard.java <==
package org.jboss.hal.testsuite.fragment.config.datasource;

import org.jboss.arquillian.graphene.Graphene;
import org.jboss.arquillian.graphene.findby.ByJQuery;
import org.jboss.hal.testsuite.fragment.shared.modal.WizardWindow;
import org.jboss.hal.testsuite.fragment.shared.table.ResourceTableFragment;
import org.jboss.hal.testsuite.fragment.shared.util.ResourceManager;
import org.jboss.hal.testsuite.util.Console;
import org.jboss.hal.testsuite.util.PropUtils;
import org.openqa.selenium.By;

/**
 * @author jcechace
 */
public class DatasourceWizard extends WizardWindow {

    private static final By DETECTED_DRIVER_BUTTON = By.xpath(".//div[text()='Detected Driver']");

    public TestConnectionWindow testConnection() {
        String label = PropUtils.get("config.datasources.configarea.connection.test.label");
        clickButton(label);
        Console.withBrowser(browser).waitUntilFinished();

        String windowTitle =  PropUtils.get("config.datasources.window.connection.test.head.label");
        TestConnectionWindow window =  Console.withBrowser(browser)
                .openedWindow(windowTitle, TestConnectionWindow.class);

        return window;
    }

    public void switchToDetectedDriver() {
        root.findElement(DETECTED_DRIVER_BUTTON).click();
    }

    public ResourceTableFragment getResourceTable() {
        return Graphene.createPageFragment(ResourceManager.class, root).getResourceTable();
    }

    /**
     * Selects datasource template time on first page of datasource wizard.
     * @param templateLabel label of template which will be used
     * @return this
     */
    public DatasourceWizard selectTemplate(String templateLabel) {
        By selectListItemSelector = ByJQuery.selector(".choose_template:contains('" + templateLabel + "')");
        getRoot().findElement(selectListItemSelector).findElement(By.tagName("input")).click();
        return this;
    }

    public void selectDriver(String driverName) {
        getResourceTable().selectRowByText(0, driverName);
    }

}
